@@ -3,25 +3,23 @@
 **
 ** <file/class description>
 **
-** Copyright (C) 2002-2004 Ingo Ralf Blum.  All rights reserved.
+** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+** 
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+** 
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
-**
-** Licensees holding an other license may use this file in accordance with 
-** the Agreement provided with the Software.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** See http://www.matroska.org/license/qpl/ for QPL licensing information.
-** See http://www.matroska.org/license/gpl/ for GPL licensing information.
+** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.
 **
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
@@ -30,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlConfig.h,v 1.7 2004/01/17 21:41:19 mosu Exp $
+	\version \$Id: EbmlConfig.h 639 2004-07-09 20:59:14Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Moritz Bunkus <moritz @ bunkus.org>
 */
@@ -38,11 +36,6 @@
 #ifndef LIBEBML_CONFIG_H
 #define LIBEBML_CONFIG_H
 
-#ifndef BIG_ENDIAN
-#define LIL_ENDIAN 0x0102
-#define BIG_ENDIAN 0x0201
-#endif
-
 // automatic endianess detection working on GCC
 #if !defined(WORDS_BIGENDIAN)
 #if (defined (__arm__) && ! defined (__ARMEB__)) || defined (__i386__) || defined (__i860__) || defined (__ns32000__) || defined (__vax__) || defined (__amd64__)
@@ -55,20 +48,13 @@
 #endif
 #endif // not autoconf
 
-// We allow the user to set the namespace for the library for cases, where the name conflicts
-#ifdef NO_NAMESPACE // for older GCC
 #define LIBEBML_NAMESPACE libebml
-#define START_LIBEBML_NAMESPACE
-#define END_LIBEBML_NAMESPACE
+#if defined(NO_NAMESPACE) // for older GCC
+# define START_LIBEBML_NAMESPACE
+# define END_LIBEBML_NAMESPACE
 #else // NO_NAMESPACE
-
-
-#ifndef LIBEBML_NAMESPACE
-#define LIBEBML_NAMESPACE libebml
-#define START_LIBEBML_NAMESPACE namespace LIBEBML_NAMESPACE {
-#define END_LIBEBML_NAMESPACE   };
-#endif // LIBEBML_NAMESPACE
-
+# define START_LIBEBML_NAMESPACE namespace LIBEBML_NAMESPACE {
+# define END_LIBEBML_NAMESPACE   };
 #endif // NO_NAMESPACE
 
 
@@ -76,23 +62,21 @@
 // we use the Win32 file API. here we set the appropriate macros.
 #if defined(_WIN32)||defined(WIN32)
 
-#if defined(EBML_DLL)
-# if defined(EBML_DLL_EXPORT)
-#  define EBML_DLL_API __declspec(dllexport)
-# else // EBML_DLL_EXPORT
-#  define EBML_DLL_API __declspec(dllimport)
-# endif // EBML_DLL_EXPORT
-#else // EBML_DLL
-# define EBML_DLL_API
-#endif // EBML_DLL
+# if defined(EBML_DLL)
+#  if defined(EBML_DLL_EXPORT)
+#   define EBML_DLL_API __declspec(dllexport)
+#  else // EBML_DLL_EXPORT
+#   define EBML_DLL_API __declspec(dllimport)
+#  endif // EBML_DLL_EXPORT
+# else // EBML_DLL
+#  define EBML_DLL_API
+# endif // EBML_DLL
 
-#define LIBEBML_WIN32
-#ifdef _MSC_VER
-#pragma warning(disable:4786)  // length of internal identifiers
-#endif // _MSC_VER
+# ifdef _MSC_VER
+#  pragma warning(disable:4786)  // length of internal identifiers
+# endif // _MSC_VER
 #else
-#define EBML_DLL_API
-#define LIBEBML_UNIX
+# define EBML_DLL_API
 #endif // WIN32 || _WIN32
 
 
@@ -110,11 +94,7 @@
 // For the moment 10 bytes Float format is not supported
 #define LIBEBML_SUPPORT_FLOAT80 0
 
-// Usefull to enforce some code behaviours
-#define DEFINE_IN_CHILD  0
-#define DEFINE_NOT_YET_IN_USE  0
-
-// For compilers that don't define __TIMSTAMP__ (e.g. gcc 2.95, gcc 3.2)
+// For compilers that don't define __TIMESTAMP__ (e.g. gcc 2.95, gcc 3.2)
 #ifndef __TIMESTAMP__
 #define __TIMESTAMP__ __DATE__ " " __TIME__
 #endif
