@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlUnicodeString.h,v 1.13 2004/04/14 23:16:31 robux4 Exp $
+	\version \$Id: EbmlUnicodeString.h 652 2004-07-21 18:09:38Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Moritz Bunkus <moritz @ bunkus.org>
 	\author Jory Stone       <jcsston @ toughguy.net>
@@ -77,7 +77,7 @@ protected:
 	size_t _Length; ///< length of the UCS string excluding the \0
 	wchar_t* _Data; ///< internal UCS representation	
 	std::string UTF8string;
-	static bool wcscmp(const wchar_t *str1, const wchar_t *str2);
+	static bool wcscmp_internal(const wchar_t *str1, const wchar_t *str2);
 	void UpdateFromUTF8();
 	void UpdateFromUCS2();
 };
