@@ -30,7 +30,7 @@
 
 /*!
     \file libebml_t.h
-    \version \$Id: libebml_t.h,v 1.5 2004/04/14 23:16:31 robux4 Exp $
+    \version \$Id: libebml_t.h 639 2004-07-09 20:59:14Z mosu $
     \author Steve Lhomme     <robux4 @ users.sf.net>
     \author Ingo Ralf Blum   <ingoralfblum @ users.sf.net>
     \author Moritz Bunkus <moritz@bunkus.org>
@@ -91,6 +91,9 @@ extern "C" {
     typedef uint16_t u_int16_t;
     typedef uint8_t  u_int8_t;
 #endif // SOLARIS
+#ifdef __BEOS__
+#include <support/SupportDefs.h>
+#else
     typedef int64_t int64;
     typedef int32_t int32;
     typedef int16_t int16;
@@ -100,6 +103,7 @@ extern "C" {
     typedef u_int32_t uint32;
     typedef u_int16_t uint16;
     typedef u_int8_t uint8;
+#endif
 #endif /* anything else */
 #endif /* _MSC_VER */
 
