@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlUnicodeString.cpp,v 1.15 2004/04/14 23:16:31 robux4 Exp $
+	\version \$Id: EbmlUnicodeString.cpp 653 2004-07-21 18:12:51Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Jory Stone       <jcsston @ toughguy.net>
 */
@@ -116,7 +116,7 @@ bool UTFstring::operator==(const UTFstring& _aStr) const
 		return true;
 	if ((_Data == NULL) || (_aStr._Data == NULL))
 		return false;
-	return (wcscmp(_Data, _aStr._Data) == 0);
+	return wcscmp_internal(_Data, _aStr._Data);
 }
 
 void UTFstring::SetUTF8(const std::string & _aStr)
@@ -193,7 +193,7 @@ void UTFstring::UpdateFromUCS2()
 
 }
 
-bool UTFstring::wcscmp(const wchar_t *str1, const wchar_t *str2)
+bool UTFstring::wcscmp_internal(const wchar_t *str1, const wchar_t *str2)
 {
 	size_t Index=0;
 	while (str1[Index] == str2[Index] && str1[Index] != 0) {
